﻿using System;
using System.Collections.Generic;
using System.Text;

using YSystem;

namespace Template
{
    /// <summary>
    /// リストマネージャクラスです。
    /// Singletonパターンです。
    /// </summary>
    public class YCListManager : YCListManagerBase
    {
        private static YCListManager _instance = null;

        private YCListManager()
            : base()
        {
        }

        public override void Dispose()
        {
            if (this.IsDisposable)
            {
                _instance = null;
            }
            base.Dispose();
        }

        //Singletonのインスタンスです。
        public static YCListManager Instance
        {
            get
            {
                if (_instance == null) _instance = new YCListManager();
                return _instance;
            }
        }

        //入力用のリスト（コードと名称のリスト）を読み込みます。
        public override void LoadLists()
        {
            //throw new YCException("YCListManager.LoadListsを実装して下さい。");

            //下記はサンプル
            try
            {
                this.OpenDialog();
                int count = 0;

                //ユーザグループ
                this.DisplayTargetListInfo("ユーザ区分", ++count);
                string sql = "SELECT Ｍユーザグループ.ユーザグループコード, Ｍユーザグループ.ユーザグループ名";
                sql += " FROM Ｍユーザグループ";
                sql += " WHERE (Ｍユーザグループ.削除フラグ = '0' OR Ｍユーザグループ.削除フラグ IS NULL)";
                sql += " ORDER BY Ｍユーザグループ.プライオリティ;";
                int idx = this.Lists.Add(new YCCodeList("ユーザグループ"));
                this.Lists[idx].SQL = sql;
                this.Lists[idx].KeyColumnName = "ユーザグループコード";
                this.Lists[idx].ValueColumnName = "ユーザグループ名";
                this.Lists[idx].Load();

                this.CloseDialog();
            }
            catch (Exception e)
            {
                try { this.CloseDialog(); }
                catch { }
                throw e;
            }
        }
    }
}
